import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  scaleOrdinal
} from 'd3';

import { loadData } from './loadData';
import { dropdownMenu } from './dropdownMenu';
import { scatterPlot } from './scatterPlot';
import { colorLegend } from './colorLegend';

// create color value
const colorScheme = [
  '#1b69a1', '#aec7e8',
  '#ff7f0e', 'yellow',
  '#2ca02c', '#98df8a',
  '#d62728', '#ff9896',
  '#9467bd', '#c5b0d5',
  '#8c564b', '#c49c94',
  '#e377c2', '#f7b6d2',
  '#7f7f7f', '#c7c7c7',
  '#bcbd22', '#dbdb8d',
  '#17becf', '#9edae5'];

let xColumn;
let yColumn;
let input;
let category;
let selectedCate;

loadData().then(data => {
  input = data;
  category = [...new Set(input.map(data => data.Major_category))];
  xColumn = data.columns[11];
  yColumn = data.columns[10];
  render();
});

const svg = select('svg');
const colorLegendG = svg.append('g')
  .attr('transform', 'translate(680, 20)');

const width = +svg.attr('width');
const height = +svg.attr('height');

const colorValue = d => d.Major_category;
const colorScale = scaleOrdinal();

const onClick = d => {
  selectedCate = d;
  render();
};

const onXColumnClicked = column => {
  xColumn = column;
  render();
};

const onYColumnClicked = column => {
  yColumn = column;
  render();
};

const render = () => {
  
  select('#x-menus')
    .call(dropdownMenu, {
      options: input.columns.filter(c => 
        c !== 'Major' &&
        c !== 'Major_category'
      ),
      onOptionClicked: onXColumnClicked,
      selectedOption: xColumn
    });
  
  select('#y-menus')
    .call(dropdownMenu, {
      options: input.columns.filter(c => 
        c !== 'Major' &&
        c !== 'Major_category'
      ),
      onOptionClicked: onYColumnClicked,
      selectedOption: yColumn
    });
  
  colorScale
    .domain(category)
    .range(colorScheme);
  
  svg.call(scatterPlot, {
    xValue: d => d[xColumn],
    xAxisLabel: xColumn,
    yValue: d => d[yColumn],
    yAxisLabel: yColumn,
    circleRadius: 6,
    margin: { top: 10, right: 290, bottom: 88, left: 100 },
    width,
    height,
    data: input,
    colorScale,
    colorValue,
    selectedCate
  });
  
  colorLegendG.call(colorLegend, {
    circleRadius: 6,
    colorScale,
    colorValue,
    selectedCate,
    onClick
  });
};

